David (name) - Wikipedia

# David (name)

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search
Male given name

David
King David
Pronunciation | /ˈdeɪvɪd/
Gender | Male
Origin
Word/name | Hebrew
Meaning | "Beloved"
Region of origin | Eretz Israel

David is a common masculine given name. It is of Biblical Hebrew origin, and its popularity derives from King David, a figure of central importance in the Hebrew Bible and in the religious traditions of Christianity, Judaism, and Islam.

## Etymology[edit]

David (Hebrew:
דָּוִד‎, Modern: David, Tiberian: Dāwîḏ) means "beloved", derived from the root dôwd (דּוֹד), which originally meant "to boil", but survives in Biblical Hebrew only in the figurative usage "to love"; specifically, it is a term for an uncle or figuratively, a lover/beloved (it is used in this way in the Song of Songs: אני לדודי ודודי לי, "I am for my beloved and my beloved is for me").[1] In Christian tradition, the name was adopted as Syriac: ܕܘܝܕ Dawid, Greek Δαυίδ, Latin Davidus or David. The Quranic spelling is دَاوُۥد Dāwūd or Dā'ūd.

David was adopted as a Christian name from an early period, e.g. David of Wales (6th century), David Saharuni (7th century), David I of Iberia (9th century). Name days are celebrated on 8 February (for David IV of Georgia), 1 March (for St. David of Wales) and 29 December (for King David), as well as 25 June (St. David of Sweden), 26 June, 9 July (Russia), 26 August, 11 December and 30 December (Hungary, Latvia, Norway, Czech Republic).

## Hypocorisms[edit]

The oldest, most popular and most commonly used diminutive form in the English speaking countries of David is Dav, which first appeared in written form in the 16th century.[citation needed] The nickname Dav or Dave has been used as a name in its own right in the 19th and 20th centuries, at least in the United States. At the height of its popularity in the 1950s and early 1960s, the name Dave was bestowed upon more than 3,000 infants each year.[2]

Other common English-language hypocorisms of the name David are Davey, Davie, and Davy. The Welsh Dafydd is also abbreviated Dewi, Dai and Daf.[3]

In Ashkenazi Jewish culture, common hypocorisms of Dovid are Dovi and Dov. Dudi is a common hypocorism in Modern Hebrew.[4]

Davo is also used as a nickname, and is quite common in Australia and Armenia, while the nickname Dato (for Davit) is popular in the country of Georgia.[citation needed]

## Female forms[edit]

Some female forms of the name are Daveigh, Davetta, Davida, and Davina. The girl's name Davinia may derive from David, but it has also been considered a derivation from the Gaelic Devin[citation needed] or a variant of Lavinia.[citation needed]

## Statistics[edit]

- United Kingdom: David was the most popular masculine given name in Northern Ireland for newborns in 1975 and dropped to a fluctuating rank around 20th in the first few years of the 21st century.[5]
- United States: David is the second most popular masculine name in the United States. 10,905,563 (1 out of 28) Americans are named David. Approximately 92,597 Davids are born each year.[6]
- United States: In 2015, the name David was the 18th most popular name for baby boys in the United States.[7]

## Variants[edit]

| This section needs additional citations for verification. Please help improve this article by adding citations to reliable sources. Unsourced material may be challenged and removed. (March 2017) (Learn how and when to remove this template message)

- Afrikaans: Dawid
- Albanian: Davidi, Dauti, Davud, Dejvid, Xhavit
- Amharic: Dawït
- Arabic:
  - Classical: داود
  - Modern: داوود (Dāwūd, Dawoud, Daoud, Dawud, Dawood)
- Aramaic: Dāwîḏ
- Armenian:
  - Classical: Դաւիթ (Dawitʻ)
  - Eastern: Դավիթ (Davitʻ)
  - Western: Դաւիթ (Tʻavitʻ)
- Assamese: দাউদ (Daud), ডেভিড (Devhid)
- Azerbaijani: Davud, داوود
- Bashkir: Дауыт (Dawït)
- Basque: Dabid
- Bosnian: Davud, Daut
- Breton: Dewi
- Bulgarian: Давид, Давидко
- Catalan: David
- Cornish: Daveth
- Croatian: David
- Czech: David, Davídek
- Danish: David
- Dutch: David
- Esperanto: Davido
- Estonian: Taavet, Taavi
- Faroese: Dávur, Dávid, Dávið, Dávi
- Filipino: David, Davide
- Finnish: Daavid, Taavetti, Taavi, Taavo
- French: David
- Fula: Dauda, Daouda
- Galician: David
- Ge'ez: Dawit
- Georgian: დავით (Davit), დათო (Dato), დათა (Data), დათუჩა (Datucha), დათიკო (Datiko), დათუნა (Datuna)
- German: David, Devid (extremely rare)
- Greek:
  - Biblical: Δαυὶδ, Δαβίδ, Δαυΐδ, Δαυείδ, Δαυίδης
  - Modern: Δαβίδ (David)
- Gujarati: ડેવિડ (Ḍēviḍa)
- Hausa: Dauda, Daouda
- Hawaiian: Kawika, Havika, Kāwika
- Hebrew: Hebrew spelling without diacritics: דוד‎, (rare) דויד‎ or full diacritics: דָּוִד‎ (David)
  - Biblical: (Dawid)
  - Tiberian: (Dāwîḏ)
- Hindi: दाऊद (Dāūd), डेविड (Ḍēviḍ)
- Hungarian: Dávid
- Icelandic: Davíð
- Indonesian: Daud
- Inuktitut: ᑖᕕᑦ (Taavit)
- Irish: Dáibhídh, Dáibhéad
- Italian: Davide
- Japanese: デイビッド (Deibiddo), ダビデ (Dabide)
- Kannada: ಡೇವಿಡ್ (Ḍēviḍ)
- Khmer: ដាវីត (Davit), ដេវីត (Dévit)
- Korean: 다윗 (Dawit)
- Latin: David, Davidus
- Latvian: Dāvids, Dāvis
- Lithuanian: Dovydas, Deividas
- Malay:
  - Malaysian: Daud, David
  - Manado: Davij, Davi, Dav, Daud
- Malayalam: ദാവീദ് (Daveedu)
- Macedonian: Давид (DeJvid)
- Mandarin Chinese:
  - Simplified: 戴维 (Dàiwéi), 大卫 (Dàwèi), 大维 (Dàwéi)
  - Traditional: 戴維 (Dàiwéi), 大衛 (Dàwèi), 大衞 (Dàwèi), 大維 (Dàwéi)
- Mandinka: Dawda, Dauda, Daouda
- Manx: Davy
- Māori: Rāwiri
- Marathi: दावीद (Dāvīda)
- Medieval English: Daw, Day
- Mi'kmaq: Dabit
- Northern Sami: Dávvet
- Northern Sotho: Dafid, Dafida
- Norwegian: David
- Persian: داوود or داود (Davud)
- Polish: Dawid
- Portuguese: David
  - Brazilian: Davi
- Punjabi: ਦਾਊਦ ਨੂੰ (Dā'ūda nū)
- Romanian: David
- Russian: Давид (Davíd), Давыд (Davýd), Дэвид (Dévid)
- Samoan: Tavita
- Scots: Dauvit, Dauid
- Scottish Gaelic: Dàibheid, Dàibhidh
- Serbian: Давид (David)
- Skolt Sami: Daa´ved
- Slovak: Dávid, David
- Slovenian: David
- Spanish: David
- Swahili: Daudi
- Swedish: David
- Syriac: ܕܘܝܕ (Dawid, Da'wood)
- Tamil: தாவீது (Daveedu)
- Telugu: దావీదు (Dáveedu)
- Thai: เดวิด (RTGS: Dewit)
- Turkish: Davut, Davud
- Ukrainian: Давид (Davyd), Devid
- Urdu: داؤد (Dāūd), ڈیوڈ (Ḍēviḍ)
- Vietnamese: Đa-vít, Đeton
- Welsh: Dafydd, Dewi, Dai, Dewydd, Day
- Wolof: Dawda, Dauda, Daouda
- Yiddish: דוד (Dóved)
- Yoruba: Dafidi, Dawodu, Dauda
- Zulu: uDavide

## See also[edit]

- All pages with titles beginning with David
- All pages with titles beginning with Dave
- List of people named David
- David (surname)
- Davide
- Dave (given name)
- Davy (given name)
- Davis (surname)
- Davies
- Devassy
- Kawika

## References[edit]

1. ^ Strong's Concordance H1732
2. ^
   "Popular Baby Names". ssa.gov.
3. ^ Although Dai was formerly used as a name in its own right prior to the late 15th century, possibly derived from a Welsh word meaning "shining". The name was very popular in Wales, leading to the situation whereby in England, "Taffy" or "Taff" (imitating the Welsh pronunciation of "Dafydd") became used as a pejorative nickname for Welshmen regardless of their actual name.[citation needed]
4. ^ Slobin, Dan Isaac (1985). The Crosslinguistic Study of Language Acquisition. ISBN 9780898593679.
5. ^ "Jack and Emma were the most popular first names in Northern Ireland in 2003" (PDF) (Press release). Northern Ireland Statistics and Research Agency. 2 January 2004. Archived from the original (PDF) on 29 September 2006. Retrieved 14 February 2008. (see tables "Comparison with 1975" and "Top 20 Names 2000–2003")
6. ^ pokemyname.com
7. ^ ourbabynamer.com

Retrieved from "https://en.wikipedia.org/w/index.php?title=David_(name)&oldid=1074261117"
Categories:

- English masculine given names
- French masculine given names
- Romanian masculine given names
- Bulgarian masculine given names
- Hebrew-language names
- Masculine given names
- German masculine given names
- Spanish masculine given names
- Swedish masculine given names
- Danish masculine given names
- Russian masculine given names
- Serbian masculine given names
- Slovene masculine given names
- Czech masculine given names
- Dutch masculine given names
- Georgian masculine given names
- Montenegrin masculine given names
- Modern names of Hebrew origin
- Given names of Hebrew language origin

Hidden categories:

- All articles with unsourced statements
- Articles with unsourced statements from March 2017
- Articles with short description
- Short description matches Wikidata
- Articles containing Syriac-language text
- Articles containing Ancient Greek (to 1453)-language text
- Articles containing Latin-language text
- Articles containing Arabic-language text
- Articles with unsourced statements from January 2016
- Articles needing additional references from March 2017
- All articles needing additional references
- Articles containing Afrikaans-language text
- Articles containing Albanian-language text
- Articles containing Amharic-language text
- Articles containing Old Armenian-language text
- Articles containing Armenian-language text
- Articles containing Western Armenian-language text
- Articles containing Assamese-language text
- Articles containing Azerbaijani-language text
- Articles containing Bashkir-language text
- Articles containing Basque-language text
- Articles containing Bosnian-language text
- Articles containing Breton-language text
- Articles containing Bulgarian-language text
- Articles containing Catalan-language text
- Articles containing Cornish-language text
- Articles containing Croatian-language text
- Articles containing Czech-language text
- Articles containing Danish-language text
- Articles containing Dutch-language text
- Articles containing Esperanto-language text
- Articles containing Estonian-language text
- Articles containing Faroese-language text
- Articles containing Filipino-language text
- Articles containing Finnish-language text
- Articles containing French-language text
- Articles containing Fula-language text
- Articles containing Galician-language text
- Articles containing Ge'ez-language text
- Articles containing Georgian-language text
- Articles containing German-language text
- Articles containing Greek-language text
- Articles containing Gujarati-language text
- Articles containing Hausa-language text
- Articles containing Hawaiian-language text
- Articles containing Hindi-language text
- Articles containing Hungarian-language text
- Articles containing Icelandic-language text
- Articles containing Indonesian-language text
- Articles containing Inuktitut-language text
- Articles containing Irish-language text
- Articles containing Italian-language text
- Articles containing Japanese-language text
- Articles containing Kannada-language text
- Articles containing Khmer-language text
- Articles containing Korean-language text
- Articles containing Latvian-language text
- Articles containing Lithuanian-language text
- Articles containing Malay (macrolanguage)-language text
- Articles containing Manado Malay-language text
- Articles containing Malayalam-language text
- Articles containing Macedonian-language text
- Articles containing Chinese-language text
- Articles containing Mandinka-language text
- Articles containing Manx-language text
- Articles containing Māori-language text
- Articles containing Marathi-language text
- Articles containing Mi'kmaq-language text
- Articles containing Northern Sami-language text
- Articles containing Northern Sotho-language text
- Articles containing Norwegian-language text
- Articles containing Persian-language text
- Articles containing Polish-language text
- Articles containing Portuguese-language text
- Articles containing Brazilian Portuguese-language text
- Articles containing Punjabi-language text
- Articles containing Romanian-language text
- Articles containing Russian-language text
- Articles containing Samoan-language text
- Articles containing Scots-language text
- Articles containing Scottish Gaelic-language text
- Articles containing Serbian-language text
- Articles containing Skolt Sami-language text
- Articles containing Slovak-language text
- Articles containing Slovene-language text
- Articles containing Spanish-language text
- Articles containing Swahili (macrolanguage)-language text
- Articles containing Swedish-language text
- Articles containing Classical Syriac-language text
- Articles containing Tamil-language text
- Articles containing Telugu-language text
- Articles containing Thai-language text
- Articles containing Turkish-language text
- Articles containing Ukrainian-language text
- Articles containing Urdu-language text
- Articles containing Vietnamese-language text
- Articles containing Welsh-language text
- Articles containing Yiddish-language text
- Articles containing Yoruba-language text
- Articles containing Zulu-language text